==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-input/lxqt-config-input_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Częstotliwość migania kursora:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Klawiatura&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Brzęczyk, gdy wystąpi błąd podczas wprowadzania z klawiatury</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Powtórzenia znaków</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Długie</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Opóźnienie powtórki:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Krótkie</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Częstotliwość powtarzania:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Zacznij pisać w okienku, aby przetestować ustawienia swojej klawiatury</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Układ klawiatury&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Układ</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Wariant</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Dodaj</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>do góry</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>w dół</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Model klawiatury:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Klawisze do zmiany układu:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Notka&lt;/span&gt;: Jeśli używasz &lt;span style=&quot; font-weight:600;&quot;&gt;metod wejścia&lt;/span&gt;, jak IBus, uim, fcitx, lub gcin, te ustawienia &lt;span style=&quot; font-weight:600;&quot;&gt;mogą nie działać&lt;/span&gt; ponieważ będą nadpisywane przez ustawienia tamtych metod.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <source>Input Device Preferences</source>
        <translation type="vanished">Preferencje urządzeń wejściowych</translation>
    </message>
    <message>
        <source>Motion</source>
        <translation type="vanished">Ruch</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Wysoka</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="vanished">Szybkie</translation>
    </message>
    <message>
        <source>Sensitivity:</source>
        <translation type="vanished">Czułość:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Niska</translation>
    </message>
    <message>
        <source>Acceleration:</source>
        <translation type="vanished">Przyspieszenie:</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation type="vanished">Wolne</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="vanished">0</translation>
    </message>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation type="vanished">Leworęczna (Zamiana lewego i prawego przycisku myszy)</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="vanished">Mysz</translation>
    </message>
    <message>
        <source>Character Repeat</source>
        <translation type="vanished">Powtórzenia znaków</translation>
    </message>
    <message>
        <source>Long</source>
        <translation type="vanished">Długie</translation>
    </message>
    <message>
        <source>Repeat delay:</source>
        <translation type="vanished">Opóźnienie powtórki:</translation>
    </message>
    <message>
        <source>Short</source>
        <translation type="vanished">Krótkie</translation>
    </message>
    <message>
        <source>Repeat interval:</source>
        <translation type="vanished">Częstotliwość powtarzania:</translation>
    </message>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation type="vanished">Zacznij pisać w okienku, aby przetestować ustawienia swojej klawiatury</translation>
    </message>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation type="vanished">Brzęczyk, gdy wystąpi błąd podczas wprowadzania z klawiatury</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="vanished">Klawiatura</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mysz&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Ruch</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Wysoka</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Szybkie</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Czułość:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Niska</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Przyspieszenie:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Wolne</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Okres podwójnego kliknięcia:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Przwijanie kółkiem (linie):</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Leworęczna (zamiana lewego i prawego przycisku myszy)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Pojedyńcze kliknięcie wyzwala akcję</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Ustawienia myszy i klawiatury</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Mysz</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Klawiatura</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Układ klawiatury</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Wybierz układ klawiatury</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Układ klawiatury</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Wariant</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-input/lxqt-config-input_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Częstotliwość migania kursora:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Klawiatura&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Brzęczyk, gdy wystąpi błąd podczas wprowadzania z klawiatury</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Powtórzenia znaków</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Długie</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Opóźnienie powtórki:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Krótkie</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Częstotliwość powtarzania:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Użyj poniższego pola, aby przetestować ustawienia swojej klawiatury</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Włącz Num Lock po zalogowaniu</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Układ klawiatury&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Układ</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Wariant</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Dodaj</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>Przenieś w górę</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>Przenieś w dół</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Model klawiatury:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Klawisze do zmiany układu:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Notka&lt;/span&gt;: Jeśli używasz &lt;span style=&quot; font-weight:600;&quot;&gt;metod wejścia&lt;/span&gt;, jak IBus, uim, fcitx, lub gcin, te ustawienia &lt;span style=&quot; font-weight:600;&quot;&gt;mogą nie działać&lt;/span&gt; ponieważ będą nadpisywane przez ustawienia tamtych metod.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <source>Input Device Preferences</source>
        <translation type="vanished">Preferencje urządzeń wejściowych</translation>
    </message>
    <message>
        <source>Motion</source>
        <translation type="vanished">Ruch</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Wysoka</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="vanished">Szybkie</translation>
    </message>
    <message>
        <source>Sensitivity:</source>
        <translation type="vanished">Czułość:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Niska</translation>
    </message>
    <message>
        <source>Acceleration:</source>
        <translation type="vanished">Przyspieszenie:</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation type="vanished">Wolne</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="vanished">0</translation>
    </message>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation type="vanished">Leworęczna (Zamiana lewego i prawego przycisku myszy)</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="vanished">Mysz</translation>
    </message>
    <message>
        <source>Character Repeat</source>
        <translation type="vanished">Powtórzenia znaków</translation>
    </message>
    <message>
        <source>Long</source>
        <translation type="vanished">Długie</translation>
    </message>
    <message>
        <source>Repeat delay:</source>
        <translation type="vanished">Opóźnienie powtórki:</translation>
    </message>
    <message>
        <source>Short</source>
        <translation type="vanished">Krótkie</translation>
    </message>
    <message>
        <source>Repeat interval:</source>
        <translation type="vanished">Częstotliwość powtarzania:</translation>
    </message>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation type="vanished">Zacznij pisać w okienku, aby przetestować ustawienia swojej klawiatury</translation>
    </message>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation type="vanished">Zabrzęcz, gdy wystąpi błąd podczas wprowadzania 
z 
klawiatury</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="vanished">Klawiatura</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formularz</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mysz&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Ruch</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Wysoka</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Szybkie</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Czułość:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Niska</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Przyspieszenie:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Wolne</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Okres podwójnego kliknięcia:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Przewijanie kółkiem (linie):</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Leworęczna (zamiana lewego i prawego przycisku myszy)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Pojedyncze kliknięcie aktywuje akcje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="46"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Ustawienia myszy i klawiatury</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Mouse</source>
        <translation>Mysz</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="56"/>
        <source>Cursor</source>
        <translation>Kursor</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="59"/>
        <source>Keyboard</source>
        <translation>Klawiatura</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="63"/>
        <source>Keyboard Layout</source>
        <translation>Układ klawiatury</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Wybierz układ klawiatury</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Układ klawiatury</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Wariant</translation>
    </message>
</context>
</TS>
